We are working on a Github page with more info at: https://tsaopy.github.io/.

We have a Zenodo DOI for referencing the repository

[![DOI](https://zenodo.org/badge/427913804.svg)](https://zenodo.org/badge/latestdoi/427913804)

# Branches

### main

This will be the current working version which includes `tsaopy` and additional testing files.

### patch/update

In progress versions with modifications of the backend. 

### pypi build

Version with the bare minimum from main plus additional installation scripts with the purpose of building the `pip install tsaopy` files.
